@@ -1,10 +1,17 @@
 import os
 import shutil
 from pathlib import Path
+from threading import Thread, current_thread
 
 from django.contrib.staticfiles import finders
 from django.core.management import BaseCommand
 
+try:
+    import requests
+except BaseException:
+    print("Requests is required try pip install requests")
+    exit(1)
+
 FLAGS = ['ad', 'ae', 'af', 'ag', 'ai', 'al', 'am', 'ao', 'aq', 'ar', 'as', 'at', 'au',
          'aw', 'ax', 'az', 'ba', 'bb', 'bd', 'be', 'bf', 'bg', 'bh', 'bi', 'bj', 'bl',
          'bm', 'bn', 'bo', 'bq', 'br', 'bs', 'bt', 'bv', 'bw', 'by', 'bz', 'ca', 'cc',
@@ -28,18 +35,57 @@ FLAGS = ['ad', 'ae', 'af', 'ag', 'ai', 'al', 'am', 'ao', 'aq', 'ar', 'as', 'at',
          'zw']
 
 
+def download(urls):
+    thread = current_thread()
+    for url in urls:
+        download_url = url[0]
+        filename = url[1]
+        print("%s) Downloading %s --> %s" % (thread.name, download_url, filename))
+        r = requests.get(download_url)
+        with open(filename, 'wb') as arch:
+            arch.write(r.content)
+
+
 class Command(BaseCommand):
     help = "Load static files for development command"
+    urls = []
+    threads_count = 10
 
-    def get_static_file(self, requests, url, basepath):
+    def get_urls_list(self, urls):
+        if self.threads_count == 1:
+            yield urls[:]
+            return
+
+        trunk_len = len(urls) // self.threads_count
+        start = 0
+        nextt = trunk_len
+        end = len(urls)
+        while nextt != end:
+            yield urls[start:nextt]
+            start = nextt
+            nextt += trunk_len
+            if nextt > end:
+                yield urls[start:]
+                nextt = end
+
+    def download_urls(self):
+        threads = []
+        for urls_trunk in self.get_urls_list(self.urls):
+            t = Thread(target=download, args=[urls_trunk])
+            t.start()
+            threads.append(t)
+
+        for t in threads:
+            t.join()
+
+    def get_static_file(self, url, basepath):
         name = url.split('/')[-1]
         if not os.path.exists(basepath / name):
-            print("Downloading %s --> %s" % (url, basepath / name))
-            r = requests.get(url)
-            with open(basepath / name, 'wb') as arch:
-                arch.write(r.content)
+            self.urls.append(
+                (url, basepath / name)
+            )
 
-    def get_static_list_file(self, requests, files, basepath):
+    def get_static_list_file(self, files, basepath):
         if not os.path.exists(basepath):
             print("Downloading %s " % (basepath,))
             with open(basepath, 'wb') as arch:
@@ -54,14 +100,11 @@ class Command(BaseCommand):
             action='store_true',
             help='Delete delete before start',
         )
+        parser.add_argument('--threads', type=int, default=10,
+                            help='Number of downloading threads')
 
     def handle(self, *args, **options):
-        try:
-            import requests
-        except BaseException:
-            print("Requests is required try pip install requests")
-            exit(1)
-
+        self.threads_count = options['threads']
         result = finders.find(Path('gentelella/css/custom.css'))
         if result is None:
             print('No static folder found')
@@ -244,23 +287,7 @@ class Command(BaseCommand):
                 'https://cdnjs.cloudflare.com/ajax/libs/Chart.js/2.9.3/Chart.min.js',
                 'https://cdnjs.cloudflare.com/ajax/libs/Chart.js/2.9.3/Chart.min.css'
             ],
-
-            'bootstrap-colorpicker': [
-                # 'https://cdnjs.cloudflare.com/ajax/libs/bootstrap-colorpicker/3.4.0/js/bootstrap-colorpicker.min.js',
-                # 'https://cdnjs.cloudflare.com/ajax/libs/bootstrap-colorpicker/3.4.0/css/bootstrap-colorpicker.css'
-                'https://colorlib.com/polygon/vendors/mjolnic-bootstrap-colorpicker/dist/css/bootstrap-colorpicker.min.css',
-                'https://colorlib.com/polygon/vendors/mjolnic-bootstrap-colorpicker/dist/js/bootstrap-colorpicker.min.js'
-            ],
             "img/": [],
-            "img/bootstrap-colorpicker": [
-                'https://colorlib.com/polygon/vendors/mjolnic-bootstrap-colorpicker/dist/img/bootstrap-colorpicker/alpha.png',
-                'https://colorlib.com/polygon/vendors/mjolnic-bootstrap-colorpicker/dist/img/bootstrap-colorpicker/hue.png',
-                'https://colorlib.com/polygon/vendors/mjolnic-bootstrap-colorpicker/dist/img/bootstrap-colorpicker/saturation.png',
-
-                'https://colorlib.com/polygon/vendors/mjolnic-bootstrap-colorpicker/dist/img/bootstrap-colorpicker/alpha-horizontal.png',
-                'https://colorlib.com/polygon/vendors/mjolnic-bootstrap-colorpicker/dist/img/bootstrap-colorpicker/hue-horizontal.png',
-                'https://colorlib.com/polygon/vendors/mjolnic-bootstrap-colorpicker/dist/img/bootstrap-colorpicker/saturation-horizontal.png',
-            ],
             'bootstrap-tree': [
                 'https://github.com/patternfly/patternfly-bootstrap-treeview/raw/master/dist/bootstrap-treeview.min.js',
                 'https://raw.githubusercontent.com/patternfly/patternfly-bootstrap-treeview/master/dist/bootstrap-treeview.min.css'
@@ -386,11 +413,12 @@ class Command(BaseCommand):
             if not os.path.exists(currentbasepath):
                 os.makedirs(currentbasepath)
             for staticfile in libs[lib]:
-                self.get_static_file(requests, staticfile, currentbasepath)
+                self.get_static_file(staticfile, currentbasepath)
 
         for files in compressed:
             for name in compressed[files]:
                 currentbasepath = basepath / files
                 currentbasepath = currentbasepath / name
-                self.get_static_list_file(requests, compressed[files][name],
+                self.get_static_list_file(compressed[files][name],
                                           currentbasepath)
+        self.download_urls()
