@@ -1,5 +1,20 @@
 document.formset = [];
 document.gtwidgets = {
+    ImageRecordInput: function(instance){
+        instance.each(function (i, e) {
+            getMediaRecord(e, 'photo');
+        });
+    },
+    VideoRecordInput: function(instance){
+        instance.each(function (i, e) {
+            getMediaRecord(e, 'video');
+        });
+    },
+    AudioRecordInput: function(instance){
+        instance.each(function (i, e) {
+            getMediaRecord(e, 'audio');
+        });
+    },
     Select: function (instance) {
         instance.each(function (i, e) {
             let s2instance=$(e);
@@ -141,6 +156,7 @@ document.gtwidgets = {
         instance.addselectwidget();
         instance.each(function (i, e) {
             let contexts2={};
+            let s2instance=$(e);
             extract_select2_context(contexts2, s2instance);
             s2instance.select2(contexts2);
         });
@@ -149,6 +165,7 @@ document.gtwidgets = {
         instance.addselectwidget();
         instance.each(function (i, e) {
             let contexts2={};
+            let s2instance=$(e);
             extract_select2_context(contexts2, s2instance);
             s2instance.select2(contexts2);
         });
@@ -193,18 +210,6 @@ document.gtwidgets = {
     NumberKnobInput: function (instance) {
         instance.knob();
     },
-    DefaultColorInput: function (instance) {
-        instance.colorpicker();
-    },
-    StyleColorInput: function (instance) {
-        instance.parent('.color-input-field').colorpicker();
-    },
-    HorizontalBarColorInput: function (instance) {
-        instance.colorpicker({ horizontal: true });
-    },
-    VerticalBarColorInput: function (instance) {
-        instance.colorpicker({ format: 'rgb' });
-    },
     TextareaWysiwyg: function (instance) {
         $(instance).removeAttr('required');
         instance.tinymce({
@@ -253,9 +258,6 @@ document.gtwidgets = {
         });
     },
 
-    InlinePickerColor: function (instance) {
-        instance.parent('.color-input-field-inline-picker').css("display", "inline-block").colorpicker({ container: true, inline: true });
-    },
     TaggingInput: function (instance) {
         instance.tagify();
     },
@@ -310,4 +312,4 @@ $(document).ready(function () {
         document.formset.push(gtformSetManager($(elem)));
     });
 
-});
\ No newline at end of file
+});
