@@ -50,6 +50,11 @@ class TextInput(Input):
     template_name = 'gentelella/widgets/text.html'
 
 
+class ColorInput(Input):
+    input_type = 'color'
+    template_name = 'gentelella/widgets/input.html'
+
+
 class HiddenInput(Input):
     input_type = 'hidden'
     template_name = 'gentelella/widgets/text.html'
@@ -164,6 +169,53 @@ class FileInput(DJFileInput):
         super().__init__(attrs)
 
 
+class ImageRecordInput(DJFileInput):
+    """
+    You can set the preview size using data-width and data-height.
+    """
+    needs_multipart_form = True
+    template_name = 'gentelella/widgets/record_photo.html'
+
+    def __init__(self, attrs=None, extraskwargs=True):
+        if extraskwargs:
+            attrs = update_kwargs(
+                attrs,
+                self.__class__.__name__,
+                base_class='d-none')
+        super().__init__(attrs)
+
+
+class VideoRecordInput(DJFileInput):
+    """
+    You can set the preview size using data-width and data-height.
+
+    .. note:: Size of video depends on camera default configuration.
+    """
+    needs_multipart_form = True
+    template_name = 'gentelella/widgets/record_video.html'
+
+    def __init__(self, attrs=None, extraskwargs=True):
+        if extraskwargs:
+            attrs = update_kwargs(
+                attrs,
+                self.__class__.__name__,
+                base_class='d-none')
+        super().__init__(attrs)
+
+
+class AudioRecordInput(DJFileInput):
+    needs_multipart_form = True
+    template_name = 'gentelella/widgets/record_audio.html'
+
+    def __init__(self, attrs=None, extraskwargs=True):
+        if extraskwargs:
+            attrs = update_kwargs(
+                attrs,
+                self.__class__.__name__,
+                base_class='d-none')
+        super().__init__(attrs)
+
+
 class ClearableFileInput(DJClearableFileInput):
     template_name = 'gentelella/widgets/file.html'
 
